@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::Moai;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 # ABSTRACT: Mojolicious UI components using modern UI libraries
 
 #pod =head1 SYNOPSIS
@@ -65,6 +65,10 @@ our $VERSION = '0.002';
 #pod
 #pod The name of the parameter to use for the current page. Defaults to C<page>.
 #pod
+#pod =item id
+#pod
+#pod An ID to add to the pager
+#pod
 #pod =back
 #pod
 #pod =head2 moai/table
@@ -104,6 +108,39 @@ our $VERSION = '0.002';
 #pod
 #pod The text to display in the column heading
 #pod
+#pod =item link_to
+#pod
+#pod Add a link to the given named route. The route will be filled in by the current
+#pod item, like C<< url_for $link_to => $item >>.
+#pod
+#pod =item id
+#pod
+#pod An ID to add to the table.
+#pod
+#pod =item class
+#pod
+#pod A hashref of additional classes to add to certain elements:
+#pod
+#pod =over
+#pod
+#pod =item * C<col> - Add these classes to every cell in the column
+#pod
+#pod =back
+#pod
+#pod =back
+#pod
+#pod =item class
+#pod
+#pod A hashref of additional classes to add to certain elements:
+#pod
+#pod =over
+#pod
+#pod =item * C<table>
+#pod
+#pod =item * C<thead>
+#pod
+#pod =item * C<wrapper> - Add a wrapper element with these classes
+#pod
 #pod =back
 #pod
 #pod =back
@@ -205,6 +242,32 @@ our $VERSION = '0.002';
 #pod
 #pod A customizable layout with good defaults.
 #pod
+#pod =item Extra Classes
+#pod
+#pod A standard way of adding extra classes to individual tags inside components. In addition
+#pod to a string, we should also support a subref so that loops can apply classes to certain
+#pod elements based on input criteria.
+#pod
+#pod =item Documentation Sheet
+#pod
+#pod Each supported library should come with a single page that demonstrates the various
+#pod widgets and provides copy/paste code snippets to achieve that widget.
+#pod
+#pod It would be amazing if there was a way to make one template apply to all
+#pod supported libraries.
+#pod
+#pod =item Content section overrides
+#pod
+#pod We cannot, should not, must not make every little thing customizable or
+#pod else our templates will be so complex as to be unmaintainable and
+#pod unusable. We should instead make content sections that can be extended,
+#pod like the C<moai/table> template could have a C<thead> section,
+#pod a C<tbody> section, and a C<tbody.tr> section.
+#pod
+#pod A rule of thumb for adding a feature should be if it can be configured simply by a single
+#pod string. The more complex the configuration needs to be, the more likely it should be
+#pod customized using L<Mojolicious's template C<extends>|Mojolicious::Guides::Rendering/Template inheritance>
+#pod
 #pod =back
 #pod
 #pod =head1 SEE ALSO
@@ -237,7 +300,7 @@ Mojolicious::Plugin::Moai - Mojolicious UI components using modern UI libraries
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -302,6 +365,10 @@ The total number of pages. Required.
 
 The name of the parameter to use for the current page. Defaults to C<page>.
 
+=item id
+
+An ID to add to the pager
+
 =back
 
 =head2 moai/table
@@ -341,6 +408,39 @@ The hash key in the item to use.
 
 The text to display in the column heading
 
+=item link_to
+
+Add a link to the given named route. The route will be filled in by the current
+item, like C<< url_for $link_to => $item >>.
+
+=item id
+
+An ID to add to the table.
+
+=item class
+
+A hashref of additional classes to add to certain elements:
+
+=over
+
+=item * C<col> - Add these classes to every cell in the column
+
+=back
+
+=back
+
+=item class
+
+A hashref of additional classes to add to certain elements:
+
+=over
+
+=item * C<table>
+
+=item * C<thead>
+
+=item * C<wrapper> - Add a wrapper element with these classes
+
 =back
 
 =back
@@ -442,6 +542,32 @@ Built-in selection of CDN-based themes for each library
 
 A customizable layout with good defaults.
 
+=item Extra Classes
+
+A standard way of adding extra classes to individual tags inside components. In addition
+to a string, we should also support a subref so that loops can apply classes to certain
+elements based on input criteria.
+
+=item Documentation Sheet
+
+Each supported library should come with a single page that demonstrates the various
+widgets and provides copy/paste code snippets to achieve that widget.
+
+It would be amazing if there was a way to make one template apply to all
+supported libraries.
+
+=item Content section overrides
+
+We cannot, should not, must not make every little thing customizable or
+else our templates will be so complex as to be unmaintainable and
+unusable. We should instead make content sections that can be extended,
+like the C<moai/table> template could have a C<thead> section,
+a C<tbody> section, and a C<tbody.tr> section.
+
+A rule of thumb for adding a feature should be if it can be configured simply by a single
+string. The more complex the configuration needs to be, the more likely it should be
+customized using L<Mojolicious's template C<extends>|Mojolicious::Guides::Rendering/Template inheritance>
+
 =back
 
 =head1 SEE ALSO
